@@ -4,8 +4,7 @@ from .constants import INSTANCES
 from .handlers import CfgParser
 
 
-def get_config(instance: str = "default", **kwargs):
-    name: str = f"{instance}.{CfgParser.__name__}"
+def get_config(name: str = "default", **kwargs):
     if name not in INSTANCES:
         # a strong reference is required
         instance: CfgParser = CfgParser(name, **kwargs)
