@@ -1,5 +1,6 @@
 # -*- coding: UTF-8 -*-
 
+from weakref import WeakValueDictionary
 from ast import literal_eval
 from configparser import ExtendedInterpolation, ConfigParser
 from decimal import Decimal
@@ -68,6 +69,8 @@ class CfgParser(ConfigParser, ArgsParser):
         "directory": ROOT,
     }
 
+    __locks__ = WeakValueDictionary()
+
     @staticmethod
     def _as_dict(mapping: Union[Dict, List[Tuple[Key, Value]]] = None, **kwargs) -> dict:
         if isinstance(mapping, list):
